@@ -1,9 +1,9 @@
 package App::ModuleFeaturesUtils;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-02-24'; # DATE
+our $DATE = '2021-02-25'; # DATE
 our $DIST = 'App-ModuleFeaturesUtils'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -53,6 +53,34 @@ _
     },
 );
 
+$SPEC{get_feature_set_spec} = {
+    v => 1.1,
+    summary => 'Get feature set specification',
+    args => {
+        %argspecreq0_feature_set,
+    },
+};
+sub get_feature_set_spec {
+    require Module::FeaturesUtil::Get;
+
+    my %args = @_;
+    [200, "OK", Module::FeaturesUtil::Get::get_feature_set_spec($args{feature_set}, 'load')];
+}
+
+$SPEC{get_features_decl} = {
+    v => 1.1,
+    summary => 'Get features declaration',
+    args => {
+        %argspecreq0_module,
+    },
+};
+sub get_features_decl {
+    require Module::FeaturesUtil::Get;
+
+    my %args = @_;
+    [200, "OK", Module::FeaturesUtil::Get::get_features_decl($args{module}, 'load')];
+}
+
 $SPEC{list_feature_sets} = {
     v => 1.1,
     summary => 'List feature sets (in modules under Module::Features:: namespace)',
@@ -224,7 +252,7 @@ App::ModuleFeaturesUtils - CLI Utilities related to Module::Features
 
 =head1 VERSION
 
-This document describes version 0.002 of App::ModuleFeaturesUtils (from Perl distribution App-ModuleFeaturesUtils), released on 2021-02-24.
+This document describes version 0.003 of App::ModuleFeaturesUtils (from Perl distribution App-ModuleFeaturesUtils), released on 2021-02-25.
 
 =head1 DESCRIPTION
 
@@ -238,6 +266,10 @@ This distribution includes the following utilities:
 
 =item * L<check-module-features>
 
+=item * L<get-feature-set-spec>
+
+=item * L<get-features-decl>
+
 =item * L<list-feature-set-features>
 
 =item * L<list-feature-sets>
@@ -354,6 +386,70 @@ Return value:  (any)
 
 
 
+=head2 get_feature_set_spec
+
+Usage:
+
+ get_feature_set_spec(%args) -> [status, msg, payload, meta]
+
+Get feature set specification.
+
+This function is not exported.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<feature_set>* => I<perl::modulefeatures::modname>
+
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (payload) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
+
+=head2 get_features_decl
+
+Usage:
+
+ get_features_decl(%args) -> [status, msg, payload, meta]
+
+Get features declaration.
+
+This function is not exported.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<module>* => I<perl::modname>
+
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (payload) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
+
 =head2 list_feature_set_features
 
 Usage:
